translate.convert.symb2po

Package translate :: Package convert :: Module symb2po |
[hide private]
[frames] | no frames]

# Module symb2po

source code

Convert Symbian localisation files to Gettext PO localization files.

Functions | [hide private]
read_header_items(ps) | source code
parse(ps) | source code
read_symbian(f) | source code
get_template_dict(template_file) | source code
build_output(units, template_header, template_dict) | source code
convert_symbian(input_file, output_file, template_file, pot=False, duplicatestyle="msgctxt") | source code
main(argv=None) | source code

Imports: factory, extractpoline, read_while, charset_re, string_entry_re, re, eat_whitespace, header_item_re, header_item_or_end_re, read_charset, ParseState, skip_no_translate, identity